| copy_files | R Documentation |
Helper function wrapped around file.copy.
copy_files(path, file_names, to, ...)
path |
character vector defining directory with files of interest. |
file_names |
character vector of file names within the directory. |
to |
character vector defining the destination directory for the files listed. |
... |
additional parameters passed to |
Basic functionality is making it simple to collapse file.copy with file.path and
ensure the copy.date is kept to TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.