| quick_copy | R Documentation |
Use regular-expressions via grepl to quickly copy files to a new location.
quick_copy(from, to, pattern, recursive = FALSE, grepl_params = list(), ...)
from, to |
character vectors, defining file paths. |
pattern |
passed to |
recursive |
passed to |
grepl_params |
additional parameters passed to |
... |
additional parameters passed to |
Operates as a helper function that wraps around grepl, list.files, and file.copy.
For another helper function in {relay} that allows file copying, see copy_files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.